@@ -2,13 +2,17 @@ package POE::Component::Client::Pastebot;
 
 use strict;
 use warnings;
+use Storable;
 use POE qw(Wheel::Run Filter::Reference);
 use LWP::UserAgent;
 use URI;
 use HTML::TokeParser;
 use vars qw($VERSION);
 
-$VERSION = '1.04';
+$VERSION = '1.06';
+
+$Storable::Deparse = 1;
+$Storable::Eval = 1;
 
 sub spawn {
   my $package = shift;
@@ -74,7 +78,7 @@ sub _spawn_wheel {
 	CloseEvent => '_child_closed',
 	StdoutEvent => '_child_stdout', 
 	StderrEvent => '_child_stderr',
-	StdioFilter => POE::Filter::Reference->new(),
+	StdioFilter => POE::Filter::Reference->new('Storable'),
 	StderrFilter => POE::Filter::Line->new(),
 	( $^O eq 'MSWin32' ? ( CloseOnCall => 0 ) : ( CloseOnCall => 1 ) ),
   );
